ExistingFileConflictPolicyKind

Enum ExistingFileConflictPolicyKind 

pub enum ExistingFileConflictPolicyKind {
    Error,
    Skip,
    Overwrite,
    OverwriteKeepingHistory,
}
Normalized per-file conflict semantics shared by direct-upload services such as Internet Archive.

Variants



Error

Fail when a file with the same name already exists.



Skip

Skip uploads whose names already exist.



Overwrite

Replace the existing file in place.



OverwriteKeepingHistory

Replace the existing file while preserving history on the remote service.