ListResourceFiles

Trait ListResourceFiles 

pub trait ListResourceFiles: ClientContext {
    type ResourceId;
    type File;

    // Required method
    fn list_resource_files(
        &self,
        id: &Self::ResourceId,
    ) -> impl Future<Output = Result<Vec<Self::File>, Self::Error>>;
}
Capability for enumerating files attached to a public resource.

Required Associated Types

type ResourceId

Service-specific resource identifier type.

type File

Service-specific file entry type.

Required Methods

fn list_resource_files( &self, id: &Self::ResourceId, ) -> impl Future<Output = Result<Vec<Self::File>, Self::Error>>

Returns the complete visible file list for the resource.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors