pub trait ResolveLatestPublicResource: ClientContext {
type ResourceId;
type Resource;
// Required method
fn resolve_latest_public_resource(
&self,
id: &Self::ResourceId,
) -> impl Future<Output = Result<Self::Resource, Self::Error>>;
}Expand description
Latest-version resolution for public resources that expose version families.
Required Associated Types
Sourcetype ResourceId
type ResourceId
Service-specific resource identifier type.
Required Methods
Sourcefn resolve_latest_public_resource(
&self,
id: &Self::ResourceId,
) -> impl Future<Output = Result<Self::Resource, Self::Error>>
fn resolve_latest_public_resource( &self, id: &Self::ResourceId, ) -> impl Future<Output = Result<Self::Resource, Self::Error>>
Resolves the latest public version in the resource family.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.